summaryrefslogtreecommitdiffstats
path: root/arch/mips/kernel/entry.S
diff options
context:
space:
mode:
authorThomas Bogendoerfer <tsbogend@alpha.franken.de>1997-07-29 21:58:04 +0000
committerThomas Bogendoerfer <tsbogend@alpha.franken.de>1997-07-29 21:58:04 +0000
commit807196c7c442fb553ea1549c82f186a795c8128b (patch)
treec519c4c1b3bff5f0938171f4c1bc54b9b3edf4a7 /arch/mips/kernel/entry.S
parent5c7d64ad04066bd3bebf092afbf0e0eb2f89557a (diff)
increased number of (working) interrupts to 32
Diffstat (limited to 'arch/mips/kernel/entry.S')
-rw-r--r--arch/mips/kernel/entry.S4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/mips/kernel/entry.S b/arch/mips/kernel/entry.S
index 682e00cda..00c321a35 100644
--- a/arch/mips/kernel/entry.S
+++ b/arch/mips/kernel/entry.S
@@ -229,10 +229,10 @@ EXPORT(exception_handlers)
.fill 32,PTRSIZE,0
/*
* Interrupt handler table with 16 entries.
*/
EXPORT(IRQ_vectors)
- .fill 16,PTRSIZE,0
+ .fill 32,PTRSIZE,0
/*
* Table of syscalls
@@ -229,10 +229,10 @@ EXPORT(exception_handlers)
.fill 32,PTRSIZE,0
/*
- * Interrupt handler table with 16 entries.
+ * Interrupt handler table with 32 entries.
*/
EXPORT(IRQ_vectors)